@@ -11,7 +11,7 @@ __doc__ = r"""
 __all__ = ["MplDrawer", "MockDrawer"]
 
 from abc import abstractmethod
-from typing import Any, Sequence, Tuple
+from typing import Any, Sequence, Tuple, MutableMapping
 
 import matplotlib
 from matplotlib import pyplot
@@ -19,6 +19,14 @@ from matplotlib import pyplot
 from draugr.drawers.drawer import Drawer
 
 
+# TODO: implement a key for closing the plot
+# close figure with spacebar
+# fig.canvas.mpl_connect('key_press_event', lambda evt: if evt.key == ' ': plt.close())
+# global solution
+# fig.canvas.mpl_connect('key_press_event', lambda evt: print(repr(evt.key))) # print key pressed
+# plt.rcParams['keymap.quit'].append(' ')
+
+
 class MplDrawer(
     # metaclass=PostInit
     Drawer
@@ -35,7 +43,7 @@ class MplDrawer(
         default_delta: float = 1 / 120,
         render: bool = True,
         placement: Tuple[int, int] = None,
-        **kwargs,
+        **kwargs: MutableMapping,
     ):
         """
 
