@@ -14,7 +14,7 @@ __all__ = ["seed_stack"]
 
 
 def seed_stack(s: int = 23) -> None:
-    """ """
+    """description"""
     from draugr.torch_utilities import torch_seed
 
     python_seed(s)
@@ -23,13 +23,13 @@ def seed_stack(s: int = 23) -> None:
 
 
 def python_seed(s: int = 2318) -> None:
-    """ """
+    """description"""
     random.seed(s)
     os.environ["PYTHONHASHSEED"] = str(s)
 
 
 def numpy_seed(s: int = 78213) -> None:
-    """ """
+    """description"""
     import numpy
 
     numpy.random.seed(s)
