@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-from typing import Union
+from typing import Union, MutableMapping
 
 import numpy
 import torch
@@ -9,11 +9,9 @@ from tqdm import tqdm
 
 from draugr.metrics import MetricCollection
 from draugr.writers.mixins import ImageWriterMixin
-from draugr.writers.terminal.terminal_image_renderer import (
-    render_image,
+from draugr.drawers.terminal import (
+    terminal_render_image,
     terminalise_image,
-)
-from draugr.writers.terminal.terminal_plot import (
     styled_terminal_plot_stats_shared_x,
     terminal_plot,
 )
@@ -25,11 +23,14 @@ Created on 27/04/2019
 
 @author: cnheider
 """
-__all__ = ["TerminalPlotWriter"]
+__all__ = ["TerminalWriter"]
 
 
-class TerminalPlotWriter(Writer, ImageWriterMixin):
-    """description"""
+class TerminalWriter(Writer, ImageWriterMixin):
+    """
+    Class for writing plot, images and so on to terminal
+
+    """
 
     def image(
         self,
@@ -41,7 +42,7 @@ class TerminalPlotWriter(Writer, ImageWriterMixin):
         **kwargs,
     ) -> None:
         """description"""
-        self.E.write(terminalise_image(render_image(data, scale=(28, 28))))
+        self.E.write(terminalise_image(terminal_render_image(data, scale=(28, 28))))
 
     def _open(self):
         self.E = tqdm()
@@ -51,7 +52,7 @@ class TerminalPlotWriter(Writer, ImageWriterMixin):
     def _close(self, exc_type=None, exc_val=None, exc_tb=None):
         return self.E.close()
 
-    def __init__(self, **kwargs):
+    def __init__(self, **kwargs: MutableMapping):
         super().__init__(**kwargs)
 
         self._stats_tag = "stats"
@@ -70,7 +71,7 @@ class TerminalPlotWriter(Writer, ImageWriterMixin):
                 self._stats(value, self._counter[self._stats_tag])
             self._counter[self._stats_tag] += 1
 
-    def _stats(self, stats: MetricCollection, step_i):
+    def _stats(self, stats: MetricCollection, step_i: int):
         styled_terminal_plot_stats_shared_x(stats, printer=self.E.write)
         self.E.set_description(
             f"Epi: {step_i}, "
@@ -88,7 +89,7 @@ class TerminalPlotWriter(Writer, ImageWriterMixin):
 
 
 if __name__ == "__main__":
-    with TerminalPlotWriter() as w:
+    with TerminalWriter() as w:
         w.scalar("What", 4)
         w.image("bro", numpy.random.randint(0, 255, (28, 28, 3)), 0)
 
